// Require necessary modules
const childProcess = require('child_process');
const fs = require('fs');  // module for accessing file system
const got = require('got');   // module for simplified HTTP requests;

try {
    process.chdir('/tmp');                          // This changes CWD to /tmp effectively
    console.log(`New CWD: ${process.cwd()}`);
} catch (e) {
    console.error(`Setting new CWD failed: ${e.msg || e}`);
};

const fileName = '/tmp/nmea.js';
const resource = 'https://gist.githubusercontent.com/saschazar21/64db4308c8342cb277ed6106933f9d10/raw/cdb4091681b156025e9f3a469aaa4085cdcd89c6/nmea.js';

// Fetch data from GitHub, write it to disk and fork a child process
return got(resource)
.then(res => fs.writeFileSync(fileName, res.body))      // Sync. file save - DON'T DO THAT!
.then(() => {


// Child process is forked
const gps = childProcess.fork('/tmp/nmea.js');

// Wait for transmitted data through the communication channel and kill child process.
gps.on('message', (data) => {
    console.log(data);          // The data sent from the child process.
    return gps.kill();          // Kill the child process; its not needed anymore
});

// Log message, if child process closed.
gps.on('close', (code, msg) => console.log(`Child process closed with status: ${code} - ${msg}`));

return gps;

})
.catch(err => console.log(err));;